==> cubes-0.9.2.tar.gz: lib/src/feedback_manager/feedback_manager.dart <==
import 'package:cubes/src/feedback_manager/bottom_sheet_feedback_mixin.dart';
import 'package:cubes/src/feedback_manager/dialog_feedback_mixin.dart';
import 'package:cubes/src/feedback_manager/snackbar_feedback_mixin.dart';
import 'package:flutter/material.dart';

export 'package:cubes/src/feedback_manager/bottom_sheet_feedback_mixin.dart';
export 'package:cubes/src/feedback_manager/dialog_feedback_mixin.dart';
export 'package:cubes/src/feedback_manager/snackbar_feedback_mixin.dart';

typedef Widget WidgetByDataBuilder<T>(T data, BuildContext context);

class FeedBackControl<T> {
  final bool show;
  final T data;

  FeedBackControl({this.show = false, this.data});

  FeedBackControl<T> copyWith({bool show, T data}) {
    return FeedBackControl(
      show: show ?? this.show,
      data: data ?? this.data,
    );
  }
}

class FeedBackManager extends StatefulWidget {
  final Widget child;

  final List<BottomSheetController> bottomSheetControllers;
  final List<DialogController> dialogControllers;
  final List<SnackBarController> snackBarControllers;
  const FeedBackManager({
    Key key,
    @required this.child,
    this.bottomSheetControllers,
    this.dialogControllers,
    this.snackBarControllers,
  }) : super(key: key);
  @override
  _FeedBackManagerState createState() => _FeedBackManagerState();
}

class _FeedBackManagerState extends State<FeedBackManager>
    with DialogFeedBackMixin, BottomSheetFeedBackMixin, SnackBarFeedBackMixin {
  @override
  void initState() {
    confBottomSheetFeedBack(widget.bottomSheetControllers);
    confDialogFeedBack(widget.dialogControllers);
    confSnackBarFeedBack(widget.snackBarControllers);
    super.initState();
  }

  @override
  Widget build(BuildContext context) => widget.child;
}

==> cubes-0.10.0.tar.gz: lib/src/feedback_manager/feedback_manager.dart <==
import 'package:cubes/src/feedback_manager/bottom_sheet_feedback_mixin.dart';
import 'package:cubes/src/feedback_manager/dialog_feedback_mixin.dart';
import 'package:cubes/src/feedback_manager/snackbar_feedback_mixin.dart';
import 'package:flutter/material.dart';

export 'package:cubes/src/feedback_manager/bottom_sheet_feedback_mixin.dart';
export 'package:cubes/src/feedback_manager/dialog_feedback_mixin.dart';
export 'package:cubes/src/feedback_manager/snackbar_feedback_mixin.dart';

typedef Widget WidgetByDataBuilder<T>(T data, BuildContext context);

class CFeedBackControl<T> {
  final bool show;
  final T data;

  CFeedBackControl({this.show = false, this.data});

  CFeedBackControl<T> copyWith({bool show, T data}) {
    return CFeedBackControl(
      show: show ?? this.show,
      data: data ?? this.data,
    );
  }
}

class CFeedBackManager extends StatefulWidget {
  final Widget child;

  final List<CBottomSheetController> bottomSheetControllers;
  final List<CDialogController> dialogControllers;
  final List<CSnackBarController> snackBarControllers;
  const CFeedBackManager({
    Key key,
    @required this.child,
    this.bottomSheetControllers,
    this.dialogControllers,
    this.snackBarControllers,
  }) : super(key: key);
  @override
  _CFeedBackManagerState createState() => _CFeedBackManagerState();
}

class _CFeedBackManagerState extends State<CFeedBackManager>
    with DialogFeedBackMixin, BottomSheetFeedBackMixin, SnackBarFeedBackMixin {
  @override
  void initState() {
    confBottomSheetFeedBack(widget.bottomSheetControllers);
    confDialogFeedBack(widget.dialogControllers);
    confSnackBarFeedBack(widget.snackBarControllers);
    super.initState();
  }

  @override
  Widget build(BuildContext context) => widget.child;
}
